#ifndef EFL_TASK_IMPL_HH
#define EFL_TASK_IMPL_HH

#include "efl_task.eo.hh"

namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::command_get() const
{
   const char * __return_value =  ::efl_task_command_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::command_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type command) const
{
    ::efl_task_command_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(command));
}
inline ::efl::eolian::return_traits< unsigned int>::type Task::arg_count_get() const
{
   unsigned int __return_value =  ::efl_task_arg_count_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::arg_value_get( ::efl::eolian::in_traits< unsigned int>::type num) const
{
   const char * __return_value =  ::efl_task_arg_value_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(num));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::arg_value_set( ::efl::eolian::in_traits< unsigned int>::type num,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type arg) const
{
    ::efl_task_arg_value_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(num)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(arg));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::env_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type var) const
{
   const char * __return_value =  ::efl_task_env_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(var));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::env_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type var,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type value) const
{
    ::efl_task_env_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(var)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(value));
}
inline ::efl::eolian::return_traits<Efl_Task_Priority>::type Task::priority_get() const
{
   Efl_Task_Priority __return_value =  ::efl_task_priority_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Task_Priority>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::priority_set( ::efl::eolian::in_traits<Efl_Task_Priority>::type priority) const
{
    ::efl_task_priority_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Task_Priority,  ::efl::eolian::in_traits<Efl_Task_Priority>::type>(priority));
}
inline ::efl::eolian::return_traits<int>::type Task::exit_code_get() const
{
   int __return_value =  ::efl_task_exit_code_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Task_Flags>::type Task::flags_get() const
{
   Efl_Task_Flags __return_value =  ::efl_task_flags_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Task_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::flags_set( ::efl::eolian::in_traits<Efl_Task_Flags>::type flags) const
{
    ::efl_task_flags_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Task_Flags,  ::efl::eolian::in_traits<Efl_Task_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<void>::type Task::arg_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type arg) const
{
    ::efl_task_arg_append(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(arg));
}
inline ::efl::eolian::return_traits<void>::type Task::arg_reset() const
{
    ::efl_task_arg_reset(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Task::env_reset() const
{
    ::efl_task_env_reset(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Task::end() const
{
    ::efl_task_end(_eo_ptr());
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::command_get() const
{
   const char * __return_value =  ::efl_task_command_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::command_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type command) const
{
    ::efl_task_command_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(command));
}
inline ::efl::eolian::return_traits< unsigned int>::type Task::arg_count_get() const
{
   unsigned int __return_value =  ::efl_task_arg_count_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::arg_value_get( ::efl::eolian::in_traits< unsigned int>::type num) const
{
   const char * __return_value =  ::efl_task_arg_value_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(num));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::arg_value_set( ::efl::eolian::in_traits< unsigned int>::type num,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type arg) const
{
    ::efl_task_arg_value_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(num)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(arg));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Task::env_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type var) const
{
   const char * __return_value =  ::efl_task_env_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(var));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::env_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type var,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type value) const
{
    ::efl_task_env_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(var)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(value));
}
inline ::efl::eolian::return_traits<Efl_Task_Priority>::type Task::priority_get() const
{
   Efl_Task_Priority __return_value =  ::efl_task_priority_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Task_Priority>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::priority_set( ::efl::eolian::in_traits<Efl_Task_Priority>::type priority) const
{
    ::efl_task_priority_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Task_Priority,  ::efl::eolian::in_traits<Efl_Task_Priority>::type>(priority));
}
inline ::efl::eolian::return_traits<int>::type Task::exit_code_get() const
{
   int __return_value =  ::efl_task_exit_code_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Task_Flags>::type Task::flags_get() const
{
   Efl_Task_Flags __return_value =  ::efl_task_flags_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Task_Flags>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Task::flags_set( ::efl::eolian::in_traits<Efl_Task_Flags>::type flags) const
{
    ::efl_task_flags_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Task_Flags,  ::efl::eolian::in_traits<Efl_Task_Flags>::type>(flags));
}
inline ::efl::eolian::return_traits<void>::type Task::arg_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type arg) const
{
    ::efl_task_arg_append(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(arg));
}
inline ::efl::eolian::return_traits<void>::type Task::arg_reset() const
{
    ::efl_task_arg_reset(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Task::env_reset() const
{
    ::efl_task_env_reset(_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Task::end() const
{
    ::efl_task_end(_eo_ptr());
}
inline efl::Task::operator ::efl::Task() const { return *static_cast< ::efl::Task const*>(static_cast<void const*>(this)); }
inline efl::Task::operator ::efl::Task&() { return *static_cast< ::efl::Task*>(static_cast<void*>(this)); }
inline efl::Task::operator ::efl::Task const&() const { return *static_cast< ::efl::Task const*>(static_cast<void const*>(this)); }
} }
#endif
